#!/bin/bash

# FoxTrot iOS sync upload script sample
# If you don't modify it, it will upload to an SFTP server, requiring installing an SSH key (read following paragraph)

sshKeyInstructions=$(cat <<'EOF'
You **MUST** have previously installed an SSH key (this script can’t use the password parameter).
Installing an SSH key **permanently** allows **any app** on this Mac to connect to an SSH/SFTP server without requiring a password.
To install an SSH key, type the following 2 command lines to a Terminal.app window (replace {user} and {host} by actual values):
    sh-keygen -f ~/.ssh/id_rsa -N ''
    ssh-copy-id {user}@{host}
See https://www.ssh.com/academy/ssh/keygen for mor info
EOF
)

# choose the protocol by uncommenting one of the following lines:
uploadProtocol="sftp"		# SSH File Transfer Protocol
# uploadProtocol="ftp"		# FTP (use TLS if the server supports it, otherwise use an unsecure connection)
# uploadProtocol="ftps"		# FTP with implicit TLS, usually on a dedicated TLS port
# uploadProtocol="ftpes"  	# FTP with explicit TLS, usually on standard port; same as ftp, but fails if the server does not support TLS

archiveFolder="$1"
archiveFilename="$2"
catalogFilename="$3"
server="$4"
username="$5"
password="$6"
port="$7"
rootPath="$8"

if [ ! -z $port ] ; then
	port=":${port}"
fi
case "$uploadProtocol" in
	"sftp")
		protocolDescription="SFTP server (SSH File Transfer Protocol)"
		;;
	"ftp")
		protocolDescription="FTP server with optional TLS"
		;;
	"ftps")
		protocolDescription="FTPS server (on a TLS-only FTP port)"
		;;
	"ftpes")
		protocolDescription="FTP server with explicit TLS (on a standard FTP port)"
		;;
esac

archivePathname="${archiveFolder}${archiveFilename}"
catalogPathname="${archiveFolder}${catalogFilename}"

if [[ "$uploadProtocol" == "sftp" ]]; then
	echo "This sample script uses the scp command line tool to upload to an $protocolDescription."
	echo "$sshKeyInstructions"
	echo
	scp -p "$archivePathname" "$catalogPathname" "scp://${username}@${server}${port}/${rootPath}"
	result="$?"
else
	echo "This sample script uses the curl command line tool to upload to an $protocolDescription."
	echo
	archiveFilenameIsoLatin=$(echo "$archiveFilename" | iconv -f UTF-8-MAC -t ISO-8859-1 --unicode-subst='?')
	userAndPass="${username}:${password}"
	if [ $uploadProtocol = "ftpes" ]; then
		urlProtocol="ftp"
	else
		urlProtocol="$uploadProtocol"
	fi
	archiveUrl="${urlProtocol}://${server}${port}${rootPath}${archiveFilenameIsoLatin}"
	catalogURL="${urlProtocol}://${server}${port}${rootPath}${catalogFilename}"
	if [ $uploadProtocol = "ftpes" ]; then
		curl -u "$userAndPass" --ssl-reqd -T "$archivePathname" "$archiveUrl" -T "$catalogPathname" "$catalogURL" -#
		result="$?"
	else
		curl -u "$userAndPass" -T "$archivePathname" "$archiveUrl" -T "$catalogPathname" "$catalogURL" -#
		result="$?"
	fi
fi

if [ $result -eq 0 ]; then
	echo "Upload succeeded"
else
	# upload will be reported as failed in the user interface if something is output to stderr, or if the script exits with a non-0 status (but the later seems unreliable)
	echo "Upload failed ###" > /dev/stderr
	exit $result
fi
